@@ -77,12 +77,12 @@ class Client:
         """
         client = cls(api_server_url, httpx_client=httpx_client)
         provider_access_token = await auth_provider.get_access_token()
-        liminal_auth_response = await client._request(
+        liminal_auth_response = await client._request(  # noqa: SLF001
             "GET",
             "/api/v1/auth/login/oauth/access-token",
             headers={"Authorization": f"Bearer {provider_access_token}"},
         )
-        client._save_session_id_from_auth_response(liminal_auth_response)
+        client._save_session_id_from_auth_response(liminal_auth_response)  # noqa: SLF001
         return client
 
     @classmethod
@@ -108,10 +108,10 @@ class Client:
 
         """
         client = cls(api_server_url, httpx_client=httpx_client)
-        session_id_response = await client._request(
+        session_id_response = await client._request(  # noqa: SLF001
             "GET", "/api/v1/users/me", cookies={"session": session_id}
         )
-        client._save_session_id_from_auth_response(session_id_response)
+        client._save_session_id_from_auth_response(session_id_response)  # noqa: SLF001
         return client
 
     @classmethod
@@ -132,12 +132,12 @@ class Client:
 
         """
         client = cls(api_server_url, httpx_client=httpx_client)
-        liminal_auth_response = await client._request(
+        liminal_auth_response = await client._request(  # noqa: SLF001
             "POST",
             "/api/v1/auth/test-automation/login",
             headers={"x-test-automation-api-key": token},
         )
-        client._save_session_id_from_auth_response(liminal_auth_response)
+        client._save_session_id_from_auth_response(liminal_auth_response)  # noqa: SLF001
         return client
 
     @property
@@ -333,14 +333,17 @@ class Client:
         cookie_jar = self._create_cookie_jar(cookies)
 
         # pylint: disable=contextmanager-generator-missing-cleanup
-        async with self._get_httpx_client() as client, client.stream(
-            method,
-            url,
-            headers=headers,
-            cookies=cookie_jar,
-            params=params,
-            json=json,
-        ) as resp:
+        async with (
+            self._get_httpx_client() as client,
+            client.stream(
+                method,
+                url,
+                headers=headers,
+                cookies=cookie_jar,
+                params=params,
+                json=json,
+            ) as resp,
+        ):
             async for line in resp.aiter_lines():
                 LOGGER.info("Received line of streaming response: %s", line)
                 yield line
