@@ -5,9 +5,13 @@ from __future__ import annotations
 from collections.abc import Awaitable, Callable
 from typing import cast
 
-from httpx import Response
-
-from liminal.endpoints.thread.models import DeidentifiedToken, Thread
+from liminal.const import SOURCE
+from liminal.endpoints.thread.models import Thread
+from liminal.endpoints.thread.schemas import (
+    CreateThreadResponse,
+    GetAvailableThreadsResponse,
+    GetThreadByIdResponse,
+)
 from liminal.helpers.typing import ValidatedResponseT
 
 
@@ -15,92 +19,82 @@ class ThreadEndpoint:
     """Define the threads endpoint."""
 
     def __init__(
-        self,
-        request: Callable[..., Awaitable[Response]],
-        request_and_validate: Callable[..., Awaitable[ValidatedResponseT]],
+        self, request_and_validate: Callable[..., Awaitable[ValidatedResponseT]]
     ) -> None:
         """Initialize.
 
         Args:
-            request: The request function.
+        ----
             request_and_validate: The request and validate function.
 
         """
-        self._request = request
         self._request_and_validate = request_and_validate
 
     async def create(self, model_instance_id: int, name: str) -> Thread:
         """Create a thread.
 
         Args:
+        ----
             model_instance_id: The model instance id.
             name: The name of the thread.
 
         Returns:
-            A Thread object representing the creatd thread.
+        -------
+            A Thread object representing the created thread.
 
         """
-        return cast(
-            Thread,
+        response = cast(
+            CreateThreadResponse,
             await self._request_and_validate(
                 "POST",
                 "/api/v1/threads",
-                Thread,
+                CreateThreadResponse,
                 json={
                     "name": name,
                     "modelInstanceId": model_instance_id,
+                    "source": SOURCE,
                 },
             ),
         )
+        return response.data
 
     async def get_available(self) -> list[Thread]:
         """Get available threads.
 
-        Returns:
+        Returns
+        -------
             A list of Thread objects.
 
         """
-        return cast(
-            list[Thread],
-            await self._request_and_validate("GET", "/api/v1/threads", list[Thread]),
+        response = cast(
+            GetAvailableThreadsResponse,
+            await self._request_and_validate(
+                "GET",
+                "/api/v1/threads",
+                GetAvailableThreadsResponse,
+                params={"source": SOURCE},
+            ),
         )
+        return response.data
 
     async def get_by_id(self, thread_id: int) -> Thread:
         """Get a thread by ID.
 
         Args:
+        ----
             thread_id: The ID of the thread.
 
         Returns:
+        -------
             A Thread object representing the thread.
 
         """
-        return cast(
-            Thread,
+        response = cast(
+            GetThreadByIdResponse,
             await self._request_and_validate(
-                "GET", f"/api/v1/threads/{thread_id}", Thread
-            ),
-        )
-
-    async def get_deidentified_context_history(
-        self, thread_id: int
-    ) -> list[DeidentifiedToken]:
-        """Get the deidentified context history for a thread.
-
-        Args:
-            thread_id: The ID of the thread.
-
-        Returns:
-            A list of DeidentifiedToken objects representing the deidentified context
-                history.
-
-        """
-        return cast(
-            list[DeidentifiedToken],
-            await self._request_and_validate(
-                "POST",
-                "/api/v1/sdk/get_context_history",
-                list[DeidentifiedToken],
-                json={"threadId": thread_id},
+                "GET",
+                f"/api/v1/threads/{thread_id}",
+                GetThreadByIdResponse,
             ),
         )
+        return response.data
